@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -287,7 +287,6 @@ void TabConfigurations::UpdateUI_Settings(UpdateUIMode mode) {
 
     if (configurator.GetActiveConfiguration() == nullptr) {
         this->_settings_tree_manager.CleanupGUI();
-        this->ui->configurations_presets->setVisible(false);
     } else {
         this->_settings_tree_manager.CreateGUI();
     }
@@ -683,12 +682,12 @@ bool TabConfigurations::EventFilter(QObject *target, QEvent *event) {
         if (right_click) {
             TreeItem *item = static_cast<TreeItem *>(this->ui->configurations_settings->itemAt(right_click->pos()));
 
-            const Configuration *configuration = configurator.GetActiveConfiguration();
-            const Parameter *parameter = configuration->GetActiveParameter();
-
-            const Layer *layer = configurator.layers.FindFromManifest(parameter->manifest);
-
             if (item != nullptr) {
+                const Configuration *configuration = configurator.GetActiveConfiguration();
+                const Parameter *parameter = configuration->GetActiveParameter();
+
+                const Layer *layer = configurator.layers.FindFromManifest(parameter->manifest);
+
                 const SettingMeta *setting = ::FindSetting(layer->settings, item->key.c_str());
                 assert(setting != nullptr);
 
