@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -58,6 +58,7 @@ TabDiagnostics::TabDiagnostics(MainWindow &window, std::shared_ptr<Ui::MainWindo
     this->connect(this->ui->diagnostic_dir_sdk, SIGNAL(clicked()), this, SLOT(on_diagnostic_dir_sdk_pressed()));
     this->connect(this->ui->diagnostic_dir_home, SIGNAL(clicked()), this, SLOT(on_diagnostic_dir_home_pressed()));
     this->connect(this->ui->diagnostic_dir_system, SIGNAL(clicked()), this, SLOT(on_diagnostic_dir_system_pressed()));
+    this->connect(this->ui->diagnostic_dir_info, SIGNAL(clicked()), this, SLOT(on_diagnostic_dir_info_pressed()));
 
     QShortcut *shortcut_search = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_F), this->ui->diagnostic_status_text);
     this->connect(shortcut_search, SIGNAL(activated()), this, SLOT(on_focus_search()));
@@ -360,6 +361,25 @@ void TabDiagnostics::on_diagnostic_dir_system_pressed() {
     QDesktopServices::openUrl(QUrl::fromLocalFile(AbsolutePath(Path::APPDATA).c_str()));
 }
 
+void TabDiagnostics::on_diagnostic_dir_info_pressed() {
+    DefaultExecutable default_executable = {
+        GetExecutable(EXECUTABLE_VKCAPSVIEWER), "vulkanCapsViewer", true, {{"Open GUI", "${VULKAN_HOME}", ""}}};
+    const Executable executable(default_executable);
+    const ExecutableOptions *options = executable.GetActiveOptions();
+
+    std::unique_ptr<QProcess> caps_viewer_process;
+    caps_viewer_process.reset(new QProcess(this));
+    // this->connect(caps_viewer_process.get(), SIGNAL(readyReadStandardOutput()), this, SLOT(standardOutputAvailable()));
+    // this->connect(caps_viewer_process.get(), SIGNAL(readyReadStandardError()), this, SLOT(errorOutputAvailable()));
+    // this->connect(caps_viewer_process.get(), SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(processClosed(int,
+    // QProcess::ExitStatus)));
+
+    caps_viewer_process->setProgram(executable.path.AbsolutePath().c_str());
+    caps_viewer_process->setWorkingDirectory(options->working_folder.AbsolutePath().c_str());
+    caps_viewer_process->setEnvironment(QProcess::systemEnvironment());
+    caps_viewer_process->startDetached();
+}
+
 void TabDiagnostics::on_refresh_log() {
     Configurator &configurator = Configurator::Get();
 
@@ -681,9 +701,10 @@ void TabDiagnostics::processClosed(int exit_code, QProcess::ExitStatus status) {
     if (!this->log_path.Empty()) {
         QFile file(this->log_path.AbsolutePath().c_str());
         const bool result = file.open(QIODevice::ReadOnly | QIODevice::Text);
-        assert(result);
-        this->status = file.readAll().toStdString();
-        file.close();
+        if (result) {
+            this->status = file.readAll().toStdString();
+            file.close();
+        }
     }
 
     this->ui->diagnostic_status_text->setText(this->status.c_str());
